@@ -81,7 +81,7 @@
                        PACKAGE="adehabitatMA")[[4]]
 
               ## computes the connex components
-              pol<-.C("getcontour", as.double(t(tmp)), as.integer(nrow(tmp)),
+              pol<-.C("getcontourc", as.double(t(tmp)), as.integer(nrow(tmp)),
                       as.integer(ncol(tmp)), integer(toto), integer(toto),
                       as.integer(toto), PACKAGE="adehabitatMA")
 
@@ -114,4 +114,3 @@
 
       return(sorties)
   }
-
